@@ -4,7 +4,7 @@ use warnings;
 
 package Test::Neo4j::Types;
 # ABSTRACT: Tools for testing Neo4j type modules
-$Test::Neo4j::Types::VERSION = '0.05';
+$Test::Neo4j::Types::VERSION = '0.08';
 
 use Test::More 0.94;
 use Test::Exception;
@@ -18,11 +18,12 @@ BEGIN { our @EXPORT = qw(
 	neo4j_point_ok
 	neo4j_datetime_ok
 	neo4j_duration_ok
+	neo4j_bytearray_ok
 )}
 
 {
-	# This happens within Neo4j/Types.pm version 1.08 and newer,
-	# but we can't be sure the installed version is that new:
+	# Workaround for warnings::register_categories() being unavailable
+	# in Perl v5.12 and earlier
 	package # local
 	        Neo4j::Types;
 	use warnings::register;
@@ -75,9 +76,9 @@ sub _element_id_test {
 			# For a missing element ID, element_id() returns the numeric ID and MUST warn
 			my @w_eid = warnings { is $id_only->$element_id(), $ID_ONLY->{$id}, "no $element_id with legacy $id" };
 			ok @w_eid, "no $element_id warns";
-			warn @w_eid if @w_eid > 1;
+			warn @w_eid if @w_eid > 1;  # uncoverable branch true
 			no warnings 'Neo4j::Types';
-			is warnings { $id_only->$element_id() }, @w_eid - 1, "no $element_id warn cat is Neo4j::Types";
+			ok 1 + warnings { $id_only->$element_id() } == @w_eid, "no $element_id warn cat is Neo4j::Types";
 		};
 	};
 }
@@ -136,7 +137,7 @@ sub _node_test {
 	my $both = { element_id => 'e17', id => 17 };
 	_element_id_test($both, $id_only, $new, $node_class, '');
 	
-	ok $n->DOES('Neo4j::Types::Node'), 'does role';
+	isa_ok $n, 'Neo4j::Types::Node';
 }
 
 
@@ -207,7 +208,7 @@ sub _relationship_test {
 	_element_id_test($both, $id_only, $new, $rel_class, 'start_');
 	_element_id_test($both, $id_only, $new, $rel_class, 'end_');
 	
-	ok $r->DOES('Neo4j::Types::Relationship'), 'does role';
+	isa_ok $r, 'Neo4j::Types::Relationship';
 }
 
 
@@ -272,7 +273,7 @@ sub _path_test {
 	is scalar(@e), 0, 'no relationships 0 gigo';
 	lives_and { is scalar($p->relationships), 0 } 'scalar context no relationships';
 	
-	ok $p->DOES('Neo4j::Types::Path'), 'does role';
+	isa_ok $p, 'Neo4j::Types::Path';
 }
 
 
@@ -337,7 +338,7 @@ sub _point_test {
 	is scalar ($p->coordinates), 2, 'scalar context undef coord';
 	
 	
-	ok $p->DOES('Neo4j::Types::Point'), 'does role';
+	isa_ok $p, 'Neo4j::Types::Point';
 }
 
 
@@ -475,7 +476,7 @@ sub _datetime_test {
 	is $dt->tz_name, undef, 'zoned datetime (too low offset): no tz_name';
 	is $dt->tz_offset, -72000, 'zoned datetime (too low offset): tz_offset';
 	
-	ok $dt->DOES('Neo4j::Types::DateTime'), 'does role';
+	isa_ok $dt, 'Neo4j::Types::DateTime';
 }
 
 
@@ -520,7 +521,7 @@ sub _duration_test {
 	is $d->seconds, 0, 'no seconds yields zero';
 	is $d->nanoseconds, 2000, 'nanoseconds';
 	
-	ok $d->DOES('Neo4j::Types::Duration'), 'does role';
+	isa_ok $d, 'Neo4j::Types::Duration';
 }
 
 
@@ -532,14 +533,44 @@ sub neo4j_duration_ok {
 }
 
 
+sub _bytearray_test {
+	my ($bytearray_class, $new) = @_;
+	
+	plan tests => 1 + 2 + 1;
+	
+	my $b;
+	
+	$b = $new->($bytearray_class, {
+		as_string => 'foo',
+	});
+	is $b->as_string, 'foo', 'bytes "foo"';
+	
+	$b = $new->($bytearray_class, {
+		as_string => "\x{100}",
+	});
+	ok ! utf8::is_utf8($b->as_string), 'wide char bytearray: UTF8 off';
+	ok length($b->as_string) > 1, 'wide char bytearray: multiple bytes';
+	
+	isa_ok $b, 'Neo4j::Types::ByteArray';
+}
+
+
+sub neo4j_bytearray_ok {
+	my ($class, $new, $name) = @_;
+	$name = "neo4j_bytearray_ok '$class'" unless defined $name;
+	_load_module_ok($name, $class) and
+	subtest $name, sub { _bytearray_test($class, $new) };
+}
+
+
 package Test::Neo4j::Types::PathNode;
-$Test::Neo4j::Types::PathNode::VERSION = '0.05';
-sub DOES { $_[1] eq 'Neo4j::Types::Node' }
+$Test::Neo4j::Types::PathNode::VERSION = '0.08';
+sub isa { $_[1] eq 'Neo4j::Types::Node' }
 
 
 package Test::Neo4j::Types::PathRel;
-$Test::Neo4j::Types::PathRel::VERSION = '0.05';
-sub DOES { $_[1] eq 'Neo4j::Types::Relationship' }
+$Test::Neo4j::Types::PathRel::VERSION = '0.08';
+sub isa { $_[1] eq 'Neo4j::Types::Relationship' }
 
 
 1;
